@@ -24,11 +24,11 @@
 */
 var NAVTREE =
 [
-  [ "FLTK 1.3.6", "index.html", [
+  [ "FLTK 1.3.9", "index.html", [
     [ "FLTK Programming Manual", "index.html", "index" ],
     [ "Todo List", "todo.html", null ],
     [ "Deprecated List", "deprecated.html", null ],
-    [ "Modules", "modules.html", "modules" ],
+    [ "Topics", "topics.html", "topics" ],
     [ "Classes", "annotated.html", [
       [ "Class List", "annotated.html", "annotated_dup" ],
       [ "Class Index", "classes.html", null ],
@@ -40,7 +40,7 @@ var NAVTREE =
         [ "Typedefs", "functions_type.html", null ],
         [ "Enumerations", "functions_enum.html", null ],
         [ "Enumerator", "functions_eval.html", null ],
-        [ "Related Functions", "functions_rela.html", null ]
+        [ "Related Symbols", "functions_rela.html", null ]
       ] ]
     ] ],
     [ "Files", "files.html", [
@@ -61,25 +61,22 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Enumerations_8H.html",
-"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a9edbfd236c9ea348dcaae935a76bd885",
-"Fl__Printer_8H.html",
-"classFl__Browser__.html#a4d59d5c7d78393a7a5d5bfaa01694580",
-"classFl__FLTK__File__Chooser.html#af31ba0b3afe6257b7ed246bf321fb8cd",
-"classFl__Graphics__Driver.html#a534f2ce7e973705cb934f6e6304d3636",
-"classFl__Input__.html#a23997fbc020994386594fbc6bb7a6548",
-"classFl__Paged__Device.html#ab91583935e45f9f85b7abf79c2bcda81",
-"classFl__Preferences_1_1Node.html#a37b1824545019d748cf00672861cc1dc",
-"classFl__Sys__Menu__Bar.html#ade5c2840df6c3b4b564c09018ff6dc0d",
-"classFl__Text__Buffer.html#aa429406d9ae922379a89519cda8b82b5",
-"classFl__Tiled__Image.html#a9d22f2345513330c2d21d11bb75f2087",
-"classFl__Tree__Item.html#a9e72a148688f46df8e87793510043032",
-"classFl__Widget.html#a7f05e24d343941328fa38958feab4168",
-"editor.html#editor_replace_dialog",
-"forms.html#forms_using",
-"group__fl__attributes.html#ga5c8dfa051e445cff49726b256b9f1ca0",
-"group__fl__drawings.html#gaf98789ec460134ffc81f2af2d2db6857",
-"group__group__comdlg.html#gad14c8bab4536ccb1ee8258bcd0f9ff1e",
-"structFl__Menu__Item.html#a996db6347b53fc0ea8ab6ae763a44a2c"
+"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcafaf89941b05600b6d4513e387d69cd36",
+"classFl.html#a43e6e0bbbc03cad134d928d4edd48d1da01d530d6bc747eb0c192038eb802a8bd",
+"classFl__Color__Chooser.html",
+"classFl__Graphics__Driver.html",
+"classFl__Image.html#a330a1e329253dd923e2a4380f705c583",
+"classFl__PNM__Image.html#a27249eef602a3d5be4adc6bbcd6f13ad",
+"classFl__Printer.html#a2b49948772a2fbe2d7a849ead465c36a",
+"classFl__Table.html#a82b1a353a6d0345e6714fb7d3a2ae0ac",
+"classFl__Text__Display.html#ae925f0bbfe42a6dc649a1fac85c13dee",
+"classFl__Tree__Item.html#a5b02fa934ba1700ae845d4f13e824195",
+"classFl__Widget.html#a3eb3b128cbad3f579a66cab813470442",
+"drawing.html#ssect_Offscreen",
+"forms.html#forms_importing",
+"group__fl__drawings.html#ga0670c9917da81b4fe67da44fd4fb4ab7",
+"group__group__comdlg.html#ga1be4def8585ff443bf26d676b3040baa",
+"structFl__Menu__Item.html#af4f5dbf86abb2d5158984a05368e923a"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
